lxc_containers = {
  haproxy = {
    server_desc = "* HAProxy (point de terminaison TLS IPv4)"
    ip_suffix   = 2
    tags = [
      "lbservers"
    ]
  }

  bt = {
    server_desc = "* Transmission\n* Sonarr\n* Jackett"
    ip_suffix   = 3
    tags = [
      "btservers",
      "resticservers",
      "webservers",
    ]
    memory_dedicated = 1024
    unprivileged     = false
    disk = [{
      size = "150G"
      path = "/var/lib/transmission-daemon"
    }]
    features = {
      nesting = true
      keyctl  = null
      fuse    = null
      mount   = ["nfs"]
    }
  }

  mail = {
    server_desc = "* Postfix\n* Postgrey\n* Dovecot\n* Spamassassin\n* OpenDKIM\n* OpenDMARC"
    ip_suffix   = 4
    tags = [
      "mailservers",
      "resticservers",
      "webservers"
    ]
    start_on_boot    = true
    memory_dedicated = 512
    disk = [{
      size = "10G"
      path = "/home"
    }]
  }

  web1 = {
    server_desc = "* Shaarli\n* FreshRSS\n* Nextcloud\n* Blog\n* Roundcube\n* Firefly3\n* Repo\n* Koillection"
    ip_suffix   = 5
    tags = [
      "pgsqlservers",
      "phpservers",
      "resticservers",
      "webservers"
    ]
    start_on_boot    = true
    cpu_cores        = 2
    memory_dedicated = 2048
    disk = [
      {
        size = "10G"
        path = "/srv"
      },
      {
        size = "5G"
        path = "/var/lib/postgresql"
      }
    ]
  }

  web2 = {
    server_desc = "* Wordpress\n* phpBB"
    ip_suffix   = 6
    tags = [
      "mariadbservers",
      "phpservers",
      "resticservers",
      "webservers"
    ]
    start_on_boot    = true
    cpu_cores        = 2
    memory_dedicated = 4096
    disk = [
      {
        size = "60G"
        path = "/srv"
      },
      {
        size = "5G"
        path = "/var/lib/mysql"
      }
    ]
  }

  voice1 = {
    server_desc = "* Mumble"
    ip_suffix   = 7
    tags = [
      "mumbleservers",
      "resticservers"
    ]
    cpu_cores        = 2
    memory_dedicated = 512
  }

  syslog = {
    server_desc = "* syslog-ng"
    ip_suffix   = 8
    tags = [
      "rsyslogservers"
    ]
    disk = [{
      size = "20G"
      path = "/srv"
    }]
  }

  voice3 = {
    server_desc = "* Icecast2"
    ip_suffix   = 9
    tags = [
      "icecastservers",
      "webservers"
    ]
  }

  jabber = {
    server_desc = "* Prosody"
    ip_suffix   = 10
    tags = [
      "resticservers",
      "webservers",
      "xmppservers"
    ]
  }

  garage1 = {
    server_desc = "* Nextcloud storage\n* Mastodon storage\n* Peertube storage"
    ip_suffix   = 11
    tags = [
      "garage_prd_cluster",
      "resticservers",
      "webservers"
    ]
    memory_dedicated = 1024
    start_on_boot    = true
    disk = [{
      size = "400G"
      path = "/var/lib/private"
    }]
  }

  munin = {
    source      = "./proxmox_lxc_container"
    server_name = "munin"
    server_desc = "* munin"
    ip_suffix   = 12
    tags = [
      "muninservers",
      "webservers"
    ]
  }

  unifi = {
    server_desc      = "* unifi server"
    ip_suffix        = 13
    memory_dedicated = 2048
  }

  ftp = {
    server_desc = "* FTP pour les caméras"
    ip_suffix   = 14
    tags = [
      "ftpservers"
    ]
    disk = [{
      size = "60G"
      path = "/srv"
    }]
  }

  dom = {
    server_desc      = "* Jeedom\n* Z-wave USB"
    ip_suffix        = 15
    memory_dedicated = 512
    start_on_boot    = true
    debian_tmpl      = "local:vztmpl/debian-11-standard_11.7-1_amd64.tar.zst"
  }

  git1 = {
    server_desc = "* Gitea"
    ip_suffix   = 16
    tags = [
      "actrunnerservers",
      "giteaservers",
      "pgsqlservers",
      "resticservers",
      "webservers",
    ]
    memory_dedicated = 1024
    cpu_cores        = 2
    features = {
      nesting = true
      keyctl  = true
      fuse    = true
      mount   = null
    }
    disk = [{
      size = "10G"
      path = "/srv"
      },
      {
        size = "10G"
        path = "/var/lib/docker"
      },
      {
        size = "5G"
        path = "/var/lib/postgresql"
      }
    ]
  }

  web3 = {
    server_desc = "* Wordpress Sebi"
    ip_suffix   = 17
    tags = [
      "mariadbservers",
      "phpservers",
      "resticservers",
      "webservers"
    ]
    memory_dedicated = 4096
    start_on_boot    = true
    started          = false
    disk = [{
      size = "10G"
      path = "/srv"
    }]
  }

  vlt1 = {
    server_desc = "* Vaultwarden"
    ip_suffix   = 18
    tags = [
      "resticservers",
      "vaultservers",
      "webservers"
    ]
  }

  masto1 = {
    server_desc = "* Mastodon"
    ip_suffix   = 19
    tags = [
      "resticservers",
      "mastodonservers",
      "pgsqlservers",
      "webservers"
    ]
    cpu_cores        = 2
    memory_dedicated = 4096
    disk = [
      {
        size = "20G"
        path = "/srv"
      },
      {
        size = "10G"
        path = "/var/lib/postgresql"
      }
    ]
  }

  pt1 = {
    server_desc = "* PeerTube"
    ip_suffix   = 20
    tags = [
      "resticservers",
      "peertubeservers",
      "pgsqlservers",
      "webservers"
    ]
    cpu_cores        = 2
    memory_dedicated = 2048
    disk = [
      {
        size = "20G"
        path = "/srv"
      },
      {
        size = "5G"
        path = "/var/lib/postgresql"
      }
    ]
  }

  es1 = {
    server_desc = "Elastic Search"
    ip_suffix   = 21
    tags = [
      "resticservers",
      "elasticsearchservers"
    ]
    memory_dedicated = 1024
    start_on_boot    = true
    disk = [{
      size = "10G"
      path = "/srv"
    }]
  }
}
